[![Build Status](https://github.com/dbbs-lab/bsb-yaml/actions/workflows/main.yml/badge.svg)](https://github.com/dbbs-lab/bsb-yaml/actions/workflows/main.yml)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# bsb-yaml

`bsb-yaml` is a plugin of [BSB](https://github.com/dbbs-lab/bsb) (see also 
[bsb-core](https://github.com/dbbs-lab/bsb-core)). 
It allows the user to write their models' configuration in the yaml format.
